]> granicus.if.org Git - sudo/commitdiff
Add missing call to save_signals().
authorTodd C. Miller <Todd.Miller@courtesan.com>
Sun, 13 Jan 2013 20:25:57 +0000 (15:25 -0500)
committerTodd C. Miller <Todd.Miller@courtesan.com>
Sun, 13 Jan 2013 20:25:57 +0000 (15:25 -0500)
--HG--
branch : 1.7

sudo.c

diff --git a/sudo.c b/sudo.c
index 1382ca812bd047b1aac608595a8545bf1d9c21e5..3e3af404ebab06d9d1c9ab07bf613b670c826e48 100644 (file)
--- a/sudo.c
+++ b/sudo.c
@@ -1107,9 +1107,10 @@ initial_setup()
     struct rlimit rl;
 #endif
 
/* Reset signal mask. */
     (void) sigemptyset(&mask);
     (void) sigprocmask(SIG_SETMASK, &mask, NULL);
+    save_signals();
 
 #if defined(__linux__)
     /*
@@ -1107,9 +1107,10 @@ initial_setup()
 #endif
 
-    /* Reset signal mask. */
+    /* Reset signal mask and save signal state. */
     (void) sigemptyset(&mask);
     (void) sigprocmask(SIG_SETMASK, &mask, NULL);